@@ -1,6 +1,7 @@
-EwLw2Series =  function(x, ew = 0.5, lw = NULL) {
-  if (is.null(lw))
+EwLw2Series <- function(x, ew = 0.5, lw = NULL) {
+  if (is.null(lw)) {
     lw <- ew
+  }
   n <- length(x$limits) - 1
   x$limits.ew <- x$limits.lw <- vector(mode = "integer", length = n)
   message(x$name)
@@ -12,8 +13,10 @@ EwLw2Series =  function(x, ew = 0.5, lw = NULL) {
     x$limits.lw[i] <- EwLw[2]
   }
   x$trw <-
-    cbind(x$trw,
-          data.frame(x$limits.ew - x$limits[1:n], x$limits[-1] - x$limits.lw))
+    cbind(
+      x$trw,
+      data.frame(x$limits.ew - x$limits[1:n], x$limits[-1] - x$limits.lw)
+    )
   colnames(x$trw) <- paste(x$name, c("trw", "ew", "lw"), sep = ".")
   return(x)
 }
