@@ -1,3 +1,3 @@
-findPeaks = function(x) {
+findPeaks <- function(x) {
   which(diff(sign(diff(x, na.pad = FALSE)), na.pad = FALSE) < 0) + 1
 }
