@@ -6,17 +6,16 @@
 #' @return an object of class "xRing" or "xRingList" without the tree-ring border at the position \code{x} for the series given by \code{series} argument
 #' @export
 #' @examples
-#'  data(PaPiRaw)
-#'  data(PaPiSpan)
-#'  PaPi <- detectRings(PaPiRaw, PaPiSpan)
-#'  plotRings(PaPi$AFO1001a)
-#'  abline(v = 60, lty = 2, col = 2) 
-#'  PaPi$AFO1001a <- removeRing(PaPi$AFO1001a, x = 60)
-#'  # PaPi$AFO1001a <- removeRing(PaPi$AFO1001a, x = locator(1)$x)
-#'  plotRings(PaPi$AFO1001a)
-#' 
-
-removeRing = function(object, x, series = NULL) {
+#' data(PaPiRaw)
+#' data(PaPiSpan)
+#' PaPi <- detectRings(PaPiRaw, PaPiSpan)
+#' plotRings(PaPi$AFO1001a)
+#' abline(v = 60, lty = 2, col = 2)
+#' PaPi$AFO1001a <- removeRing(PaPi$AFO1001a, x = 60)
+#' # PaPi$AFO1001a <- removeRing(PaPi$AFO1001a, x = locator(1)$x)
+#' plotRings(PaPi$AFO1001a)
+#'
+removeRing <- function(object, x, series = NULL) {
   if (!any(c("xRingList", "xRing") %in% class(object))) {
     stop("Use only with \"xRingList\" and \"xRing\" objects.")
   }
@@ -25,6 +24,5 @@ removeRing = function(object, x, series = NULL) {
     object[[series]] <- removeRingSeries(object[[series]], x)
     return(object)
   }
-  x <- removeRingSeries(object, x)
-  return(x)
+  removeRingSeries(object, x)
 }
