@@ -1,5 +1,5 @@
 
-setFirstYear = function (rwl, n = 0) {
+setFirstYear <- function(rwl, n = 0) {
   rownames(rwl) <- as.integer(rownames(rwl)) + n
   as.data.frame(rwl)
 }
