@@ -7,17 +7,15 @@
 #' @return the modified input object with new set last ring of the specified series.
 #' @export
 #' @examples
-#' 
-#'  data(PaPiRaw)
-#'  data(PaPiSpan)
-#'  PaPi <- detectRings(PaPiRaw, PaPiSpan)
-#'  plot(PaPi, series = "AFO1001b")
-#'  PaPi <- setLastYear(PaPi, 2005, series = "AFO1001b")
-#'  plot(PaPi, series = "AFO1001b")
-#' 
-
-
-setLastYear = function(x, lastYear, series = NULL) {
+#'
+#' data(PaPiRaw)
+#' data(PaPiSpan)
+#' PaPi <- detectRings(PaPiRaw, PaPiSpan)
+#' plot(PaPi, series = "AFO1001b")
+#' PaPi <- setLastYear(PaPi, 2005, series = "AFO1001b")
+#' plot(PaPi, series = "AFO1001b")
+#'
+setLastYear <- function(x, lastYear, series = NULL) {
   if (!any(c("xRingList", "xRing") %in% class(x))) {
     stop("Use only with \"xRingList\" and \"xRing\" objects.")
   }
