@@ -1,4 +1,4 @@
-setLastYearSeries = function(x, lastYear) {
+setLastYearSeries <- function(x, lastYear) {
   x$years <- lastYear - ((length(x$years) - 1):0)
   rownames(x$trw) <- x$years[-1]
   x$span <- range(x$years)
