@@ -1,5 +1,5 @@
-setName = function(x, newName) {
+setName <- function(x, newName) {
   colnames(x$trw) <- newName
   x$name <- newName
-  return(x)
+  x
 }
